@@ -11,8 +11,8 @@ class PayPalIPNAdmin(admin.ModelAdmin):
             "fields": [
                 "flag", "txn_id", "txn_type", "payment_status", "payment_date",
                 "transaction_entity", "reason_code", "pending_reason",
-                "mc_gross", "mc_fee", "auth_status", "auth_amount", "auth_exp",
-                "auth_id"
+                "mc_currency", "mc_gross", "mc_fee", "mc_handling", "mc_shipping",
+                "auth_status", "auth_amount", "auth_exp", "auth_id"
             ]
         }),
         ("Address", {
