@@ -204,6 +204,7 @@ class PayPalStandardBase(Model):
 
     class Meta:
         abstract = True
+        app_label = 'paypal_standard_base' # Keep Django 1.7 quiet
 
     def __unicode__(self):
         if self.is_transaction():
@@ -266,6 +267,12 @@ class PayPalStandardBase(Model):
     def is_recurring_failed(self):
         return self.txn_type == "recurring_payment_failed"
 
+    def is_recurring_suspended(self):
+        return self.txn_type == "recurring_payment_suspended"
+
+    def is_recurring_suspended_due_to_max_failed_payment(self):
+        return self.txn_type == "recurring_payment_suspended_due_to_max_failed_payment"
+
     def is_billing_agreement(self):
         return len(self.mp_id) > 0
 
