@@ -6,6 +6,8 @@ import os
 from django.conf import settings
 from django.shortcuts import render_to_response
 from django.test import TestCase
+from django.test.utils import override_settings
+
 from paypal.standard.pdt.models import PayPalPDT
 
 
@@ -19,11 +21,11 @@ class DummyPayPalPDT(object):
         self.response = ''
 
     def update_with_get_params(self, get_params):
-        if get_params.has_key('tx'):
+        if 'tx' in get_params:
             self.context_dict['txn_id'] = get_params.get('tx')
-        if get_params.has_key('amt'):
+        if 'amt' in get_params:
             self.context_dict['mc_gross'] = get_params.get('amt')
-        if get_params.has_key('cm'):
+        if 'cm' in get_params:
             self.context_dict['custom'] = get_params.get('cm')
 
     def _postback(self, test=True):
@@ -31,8 +33,8 @@ class DummyPayPalPDT(object):
         return render_to_response("pdt/test_pdt_response.html", self.context_dict).content
 
 
+@override_settings(ROOT_URLCONF="paypal.standard.pdt.tests.test_urls")
 class PDTTest(TestCase):
-    urls = "paypal.standard.pdt.tests.test_urls"
     template_dirs = [os.path.join(os.path.dirname(__file__), 'templates'), ]
 
     def setUp(self):
@@ -53,7 +55,7 @@ class PDTTest(TestCase):
 
     def test_verify_postback(self):
         dpppdt = DummyPayPalPDT()
-        paypal_response = dpppdt._postback()
+        paypal_response = dpppdt._postback().decode('ascii')
         assert ('SUCCESS' in paypal_response)
         self.assertEqual(len(PayPalPDT.objects.all()), 0)
         pdt_obj = PayPalPDT()
